@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: wai
-version: 3.2.0.1
-id: wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
-key: wai_6Pi7BTumKrYJiMU4SY1oRL
+version: 3.2.0
+id: wai-3.2.0-61d8ab991e10dd6c5057d0dabf632d2a
+key: wai_B6LPPWzEV1d9CAgeYz0yqv
 license: MIT
 maintainer: michael@snoyman.com
 stability: Stable
@@ -17,19 +17,19 @@ exposed: True
 exposed-modules:
     Network.Wai Network.Wai.Internal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-3.2.0.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-3.2.0.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-3.2.0.1
-hs-libraries: HSwai-3.2.0.1-6Pi7BTumKrYJiMU4SY1oRL
+import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-3.2.0
+library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-3.2.0
+data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-3.2.0
+hs-libraries: HSwai-3.2.0-B6LPPWzEV1d9CAgeYz0yqv
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
+    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    vault-0.3.0.6-2c2444df5306907b16aaa509d25c29c9
+    vault-0.3.0.6-8b1ddbd07c6eb1be1ee9aee781649e3c
 haddock-interfaces: /usr/share/doc/haskell-wai/html/wai.haddock
 haddock-html: /usr/share/doc/haskell-wai/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
